@@ -22,9 +22,7 @@
 #include "pw_framebuffer.h"
 #include <KPluginFactory>
 
-
-K_PLUGIN_FACTORY_WITH_JSON(PWFrameBufferPluginFactory, "krfb_framebuffer_pw.json",
-               registerPlugin<PWFrameBufferPlugin>();)
+K_PLUGIN_CLASS(PWFrameBufferPlugin)
 
 PWFrameBufferPlugin::PWFrameBufferPlugin(QObject *parent, const QVariantList &args)
     : FrameBufferPlugin(parent, args)
@@ -32,15 +30,9 @@ PWFrameBufferPlugin::PWFrameBufferPlugin(QObject *parent, const QVariantList &ar
 }
 
 
-PWFrameBufferPlugin::~PWFrameBufferPlugin()
+FrameBuffer *PWFrameBufferPlugin::frameBuffer(const QVariantMap &args)
 {
-}
-
-FrameBuffer *PWFrameBufferPlugin::frameBuffer(WId id, const QVariantMap &args)
-{
-    //NOTE WId is irrelevant in Wayland
-
-    auto pwfb = new PWFrameBuffer(id);
+    auto pwfb = new PWFrameBuffer;
     if (args.contains(QLatin1String("name"))) {
         pwfb->startVirtualMonitor(args[QStringLiteral("name")].toString(), args[QStringLiteral("resolution")].toSize(), args[QStringLiteral("scale")].toDouble());
     } else {
