@@ -29,7 +29,7 @@ class KRFBPRIVATE_EXPORT FrameBuffer : public QObject
 {
     Q_OBJECT
 public:
-    explicit FrameBuffer(WId id, QObject *parent = nullptr);
+    explicit FrameBuffer(QObject *parent = nullptr);
 
     ~FrameBuffer() override;
 
@@ -52,7 +52,6 @@ Q_SIGNALS:
     void frameBufferChanged();
 
 protected:
-    WId win;
     char *fb = nullptr;
     QList<QRect> tiles;
 
